@@ -169,15 +169,14 @@ class DcsConnection:
     def __stop__(self):
         logging.debug("Threads stopping...")
         self.__connected__ = False
-        self.__threadLock__.acquire()
-        self.__running__ = False
-        self.__threadLock__.release()
-        if(self.__receiverThread__ != None and self.__receiverThread__.is_alive()):
-            self.__receiverThread__.join(JOINTIMEOUT)
-        logging.debug("Receiver stopped. ")
-        if(self.__workerThread__ != None and self.__workerThread__.is_alive()):
-            self.__workerThread__.join(JOINTIMEOUT)
-        logging.debug("Worker stopped.")
+        with self.__threadLock__:
+            self.__running__ = False
+            if(self.__receiverThread__ != None and self.__receiverThread__.is_alive()):
+                self.__receiverThread__.join(JOINTIMEOUT)
+            logging.debug("Receiver stopped. ")
+            if(self.__workerThread__ != None and self.__workerThread__.is_alive()):
+                self.__workerThread__.join(JOINTIMEOUT)
+            logging.debug("Worker stopped.")
 
     ##receiving messages
     def __receive__(self):
@@ -336,11 +335,11 @@ class DcsConnection:
         logging.info(str(id(self)) + " TID: " + str(tid) + "; Unknown MSG-Type received: " + str(msgtype) + ".")
     
     def watchdog(self):
-        logging.info(str(id(self)) + " DCS-Watchdog running...")
+        logging.debug(str(id(self)) + " DCS-Watchdog running...")
         with self.__threadLock__:
             if(self.__running__ != True):
-                logging.warning(str(id(self)) + "DCS-Connection ist stopped.")
-                return
+                logging.warning(str(id(self)) + "DCS-Watchdog: DCS-Connection ist stopped.")
+                return self.__running__
 
             if(self.__receiverThread__ != None and not self.__receiverThread__.is_alive()):
                 logging.warning(str(id(self)) + " Receiver thread death. Restarting...")
@@ -381,6 +380,7 @@ class DcsConnection:
                 logging.warning(str(id(self)) + "Cannot check socket. " + str(e))
 
         logging.debug(str(id(self)) + " MSQ-Size: " + str(self.__receivedMessageQueue__.qsize()))
+        return self.__running__
 
     def __cleanSentrequests__(self):
         with self.__messageLock__:
@@ -1127,18 +1127,31 @@ if __name__ == "__main__":
     ## watchdog tests
     connection = DcsConnection(serial, cryptoKey, server, 50333)
     try:
-        connection.watchdog()
-        print(color('SUCCESS: Watchdog without started connection.', fore='green', style='bright'))
-    except:
-        print(color('ERROR: Watchdog without started connection.', fore='red', style='bright'))
+        if(connection.watchdog() == False):
+            print(color('SUCCESS: Watchdog without started connection.', fore='green', style='bright'))
+        else:
+            raise Exception("connection running.")
+    except Exception as e:
+        print(color('ERROR: Watchdog without started connection. ' + str(e), fore='red', style='bright'))
     connection.connect()
     try:
-        connection.watchdog()
-        print(color('SUCCESS: Watchdog with started connection.', fore='green', style='bright'))
-    except:
-        print(color('ERROR: Watchdog with started connection.', fore='red', style='bright'))
+        if(connection.watchdog()):
+            print(color('SUCCESS: Watchdog with started connection.', fore='green', style='bright'))
+        else:
+            raise Exception("connection not running.")
+    except Exception as e:
+        print(color('ERROR: Watchdog with started connection. ' + str(e), fore='red', style='bright'))
     connection.disconnect()
 
+    time.sleep(10)
+    try:
+        if(connection.watchdog() == False):
+            print(color('SUCCESS: Watchdog with after disconnecting.', fore='green', style='bright'))
+        else:
+            raise Exception("connection not disconnected.")
+    except Exception as e:
+        print(color('ERROR: Watchdog with after disconnecting. ' + str(e), fore='red', style='bright'))
+
     input(color('[DCS-Connection] AUTO-Tests finished. Press enter to continue...', fore='blue', style='bright'))
 
     connection = DcsConnection(serial, cryptoKey, server, 50333)
