@@ -118,7 +118,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             "ww2target": self.getdataset("boost_temp_target"),
             "ww2offset": self.getdataset("ww2offset_calibration"),
             "modbuserrorrate":  errorrate,
-            "errorcode": errorcode
+            "errorcode_elwa": errorcode
         }       
         return data
 
